==> aloe-1.4.1.tar.gz: aloe-1.4.1/modules/gen_detectpreamble/interfaces/stats.h <==

#ifndef _STATS_H
#define	_STATS_H

int stat_corr,stat_start,stat_seq,stat_preatt,stat_det,stat_out,stat_offset;

#define MAX_SEQ_LEN 1024

int correlation[MAX_SEQ_LEN];

int datatype;
int det_threshold,symbol_rate,scale,frame_size;

int FilterType=0,Ntaps;
float alpha;

    int start_sample,offset;
    int preatt;

int sequence[MAX_SEQ_LEN];

int output_i[MAX_SEQ_LEN];

struct utils_param params[] = {
    {"datatype",STAT_TYPE_INT,1,&datatype},
    {"frame_size",STAT_TYPE_INT,1,&frame_size},
    {"detection_threshold",STAT_TYPE_INT,1,&det_threshold},
    {"symbol_rate",STAT_TYPE_INT,1,&symbol_rate},
    {"offset",STAT_TYPE_INT,1,&offset},
    {"scale",STAT_TYPE_INT,1,&scale},
    {"preatt",STAT_TYPE_INT,1,&preatt},
        /** filter type
     * 0 rect
     * 1 raised cosine
     * 2 root-raised cosine
     */
    {"filter_type",STAT_TYPE_INT,1,&FilterType},
    {"alpha",STAT_TYPE_FLOAT,1,&alpha},
    {"ntaps",STAT_TYPE_INT,1,&Ntaps},

                            {NULL, 0, 0, 0}};

struct utils_stat stats[] = {

                            {"threshold",
                            STAT_TYPE_INT,
                            1,
                            &stat_det,
                            (void*)&det_threshold,
                            READ},

                             {"correlation",
                            STAT_TYPE_INT,
                            MAX_SEQ_LEN,
                            &stat_corr,
                            (void*)correlation,
                            WRITE},

                            {"output_signal",
                            STAT_TYPE_INT,
                            MAX_SEQ_LEN,
                            &stat_out,
                            (void*)output_i,
                            WRITE},

                             {"sequence",
                            STAT_TYPE_INT,
                            MAX_SEQ_LEN,
                            &stat_seq,
                            (void*)sequence,
                            WRITE},

                            {"start_sample",
                            STAT_TYPE_INT,
                            1,
                            &stat_start,
                            (void*)&start_sample,
                            WRITE},

                            {"offset",
                            STAT_TYPE_INT,
                            1,
                            &stat_offset,
                            (void*)&offset,
                            READ},

                            {"preatt",
                            STAT_TYPE_INT,
                            1,
                            &stat_preatt,
                            (void*)&preatt,
                            READ},

                            {NULL, 0, 0, 0, 0, 0}};


#endif	/* _STATS_H */

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/gen_detectpreamble/interfaces/stats.h <==

#ifndef _STATS_H
#define	_STATS_H

int stat_corr,stat_start,stat_seq,stat_stth,stat_stlen,stat_preatt,stat_det,stat_out,stat_offset;

#define MAX_SEQ_LEN 1024

int correlation[MAX_SEQ_LEN];

int datatype;
int det_threshold,frame_size;

int start_sample,offset;
int start_len;
int start_th;

int sequence[MAX_SEQ_LEN];

int output_i[MAX_SEQ_LEN];

struct utils_param params[] = {
    {"datatype",STAT_TYPE_INT,1,&datatype},
    {"frame_size",STAT_TYPE_INT,1,&frame_size},
    {"detection_threshold",STAT_TYPE_INT,1,&det_threshold},
    {"offset",STAT_TYPE_INT,1,&offset},
    {"start_len",STAT_TYPE_INT,1,&start_len},
    {"start_th",STAT_TYPE_INT,1,&start_th},



                            {NULL, 0, 0, 0}};

struct utils_stat stats[] = {

                            {"threshold",
                            STAT_TYPE_INT,
                            1,
                            &stat_det,
                            (void*)&det_threshold,
                            READ},

                             {"correlation",
                            STAT_TYPE_INT,
                            MAX_SEQ_LEN,
                            &stat_corr,
                            (void*)correlation,
                            WRITE},

                            {"output_signal",
                            STAT_TYPE_INT,
                            MAX_SEQ_LEN,
                            &stat_out,
                            (void*)output_i,
                            WRITE},

                             {"sequence",
                            STAT_TYPE_INT,
                            MAX_SEQ_LEN,
                            &stat_seq,
                            (void*)sequence,
                            WRITE},

                            {"start_sample",
                            STAT_TYPE_INT,
                            1,
                            &stat_start,
                            (void*)&start_sample,
                            WRITE},

                            {"offset",
                            STAT_TYPE_INT,
                            1,
                            &stat_offset,
                            (void*)&offset,
                            READ},

                            {"start_len",
						   STAT_TYPE_INT,
						   1,
						   &stat_stlen,
						   (void*)&start_len,
						   READ},
                           {"start_th",
						   STAT_TYPE_INT,
						   1,
						   &stat_stth,
						   (void*)&start_th,
						   READ},

                            {NULL, 0, 0, 0, 0, 0}};


#endif	/* _STATS_H */
